@@ -17,24 +17,26 @@
 ######################################################################################################################################
 
 MiSSE <- function(phy, f=1, turnover=c(1,2), eps=c(1,2), condition.on.survival=TRUE, root.type="madfitz", root.p=NULL, sann=FALSE, sann.its=10000, bounded.search=TRUE, max.tol=.Machine$double.eps^.50, starting.vals=NULL, turnover.upper=10000, eps.upper=3, trans.upper=100, restart.obj=NULL, ode.eps=0){
-
+    
     ## Temporary fix for the current BUG:
     if( !is.null(phy$node.label) ) phy$node.label <- NULL
-
+    
     if(!is.null(root.p)) {
-        root.type="user"
         root.p <- root.p / sum(root.p)
-        if(hidden.states ==TRUE & length(root.p)==4){
-            root.p <- rep(root.p, 4)
-            root.p <- root.p / sum(root.p)
-            warning("For hidden states, you need to specify the root.p for all four hidden states. We have adjusted it so that there's equal chance for 0A as 0B, and for 1A as 1B")
+        if(hidden.states ==TRUE){
+            if(length(root.p) < 26){
+                root.p.new <- numeric(26)
+                root.p.new[1:length(root.p)] <- root.p
+                root.p <- root.p.new
+                root.p <- root.p / sum(root.p)
+            }
         }
     }
 
     if(!root.type == "madfitz" & !root.type == "herr_als"){
         stop("Check that you specified a proper root.type option. Options are 'madfitz' or 'herr_als'. See help for more details.", call.=FALSE)
     }
-
+    
     if(length(turnover) != length(eps)){
         stop("The number of turnover parameters need to match the number of extinction fraction parameters.", call.=FALSE)
     }
