@@ -20,6 +20,7 @@ extern void initmod_fgeohisse();
 extern void initmod_fhinoclass();
 extern void initmod_fgeosse();
 extern void initmod_fnoclass();
+extern void initmod_misse();
 
 extern void maddison_DE_bisse(void *, void *, void *, void *, void *, void *);
 extern void maddison_DE_hisse(void *, void *, void *, void *, void *, void *);
@@ -34,6 +35,7 @@ extern void fgeohisse_derivs(void *, void *, void *, void *, void *, void *);
 extern void fnotclasse_more_derivs(void *, void *, void *, void *, void *, void *);
 extern void fclasse_geosse_equivalent_derivs(void *, void *, void *, void *, void *, void *);
 extern void fnotclasse_derivs(void *, void *, void *, void *, void *, void *);
+extern void misse_derivs(void *, void *, void *, void *, void *, void *);
 
 extern void set_birth_bisse_void(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void set_birth_hisse_null_void(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
@@ -53,6 +55,7 @@ static const R_CMethodDef CEntries[] = {
     {"initmod_fhinoclass",		        (DL_FUNC) &initmod_fhinoclass,              0},
     {"initmod_fgeosse",		            (DL_FUNC) &initmod_fgeosse,                 0},
     {"initmod_fnoclass",		        (DL_FUNC) &initmod_fnoclass,                0},
+    {"initmod_misse",		            (DL_FUNC) &initmod_misse,                   0},
     {"maddison_DE_bisse",               (DL_FUNC) &maddison_DE_bisse,               6},
     {"maddison_DE_hisse",               (DL_FUNC) &maddison_DE_hisse,               6},
     {"maddison_DE_hisse_null",          (DL_FUNC) &maddison_DE_hisse_null,          6},
@@ -66,6 +69,7 @@ static const R_CMethodDef CEntries[] = {
     {"fnotclasse_more_derivs",          (DL_FUNC) &fnotclasse_more_derivs,          6},
     {"fclasse_geosse_equivalent_derivs",(DL_FUNC) &fclasse_geosse_equivalent_derivs,6},
     {"fnotclasse_derivs",               (DL_FUNC) &fnotclasse_derivs,               6},
+    {"misse_derivs",                    (DL_FUNC) &misse_derivs,                    6},
     {"set_birth_bisse_void",            (DL_FUNC) &set_birth_bisse_void,           29},
     {"set_birth_hisse_null_void",       (DL_FUNC) &set_birth_hisse_null_void,      54},
     {"set_birth_hisse_void",            (DL_FUNC) &set_birth_hisse_void,           59},
